@@ -24,7 +24,7 @@ def scan_type(stype):
 
 
 def main():
-    if (argv[1] == '-v'):
+    if (len(argv) == 2 and argv[1] == '-v'):
         print("[bold green]Webhawk 0.1.0[/bold green]")
         exit(0)
 
